/*--------------------------------------------------------------
 *  Copyright (c) 2005 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
 *
 *  NAME:     ddlhcm.sas
 *
 *  PURPOSE:  Macro to create all the HCM data mart tables in the MySQL database
 *
 *
 *  USAGE:    Run during the HCM install.
 *
 *  LIBREF    Libref to the MySQL database library
 *  DTTMFMT   DATETIME21., default format for datetime
 *  DTFMT     DATE9., default format for date
 *
 *  EXAMPLE:
 *
 *     %%ddlhcm(libref=HCMData);
 *
 *
 *  NOTES:
 *
 *-------------------------------------------------------------*/
%macro ddlhcm(LIBREF=HCMDATA,DTTMFMT=DATETIME21., DTFMT=DATE9.);

/* set the locale macro variables */
%setlocs;

/* define the label macros for the build programs to use */
%readlbls(basedir=&propspth,basefile=&lblprops,baseext=properties,slash=&slash,defaultpath=);


options metarepository="&HRRepos";
%LibConOp(sesetl_sasLibRef=&LIBREF,
         sesetl_ChkDepRepos=Y
         ) ;
run;
PROC SQL;

connect to &sesetl_EngineType as PASSTHRU (&sesetl_BestLogin &sesetl_ConnectionOptions );


execute(
         CREATE TABLE  ABSHIST (
             ABSENCE_ID           VARCHAR(32)    ,
             EMPLOYEE_ID          VARCHAR(32)    ,
             ABSENCE_TYPE_CD      VARCHAR(10)    ,
             ABSENCE_START_DT     DATE           ,
             ABSENCE_END_DT       DATE           ,
             DURATION_QTY         NUMERIC(8)     ,
             DURATION_TIME_UOM_CD VARCHAR(3)
                ) TYPE=InnoDB
        ) by PASSTHRU;

execute(
         CREATE TABLE  ABSHMAST (
                ABSENCE_END_DT            DATE,
                ABSENCE_ID                VARCHAR(32),
                ABSENCE_MONTH             NUMERIC(8),
                ABSENCE_START_DT          DATE,
                ABSENCE_TYPE_CD           VARCHAR(10),
                ABSENCE_YEAR              NUMERIC(8),
                AGE                       NUMERIC(8),
                AGE_RANGE                 VARCHAR(15),
                BDAY                      NUMERIC(8),
                BIRTH_DT                  DATE,
                CITY_NM                   VARCHAR(100),
                DISABILITY_FLG            VARCHAR(1),
                DURATION_QTY              NUMERIC(8),
                DURATION_TIME_UOM_CD      VARCHAR(3),
                EEO_CLASS_CD              VARCHAR(10),
                EMPLOYEE_ID               VARCHAR(32),
                EMPLOYEE_NAME             VARCHAR(60),
                EMPLOYEE_NO               VARCHAR(20),
                ETHNICITY_CD              VARCHAR(10),
                EXEMPT_STATUS_CD          VARCHAR(10),
                GENDER_CD                 VARCHAR(3),
                HIRE_DT                   DATE,
                INTERNAL_ORG_ID           VARCHAR(32),
                INTORG_HR                 VARCHAR(32),
                INTORG_HR1                VARCHAR(32),
                INTORG_HR2                VARCHAR(32),
                INTORG_HR3                VARCHAR(32),
                INTORG_HR4                VARCHAR(32),
                INTORG_HR5                VARCHAR(32),
                INTORG_MGR                VARCHAR(32),
                INTORG_MGR1               VARCHAR(32),
                INTORG_MGR2               VARCHAR(32),
                INTORG_MGR3               VARCHAR(32),
                INTORG_MGR4               VARCHAR(32),
                INTORG_MGR5               VARCHAR(32),
                JOB_CD                    VARCHAR(10),
                JOB_GROUP_CD              VARCHAR(10),
                JOB_GROUP_DESC            VARCHAR(255),
                JOB_TITLE_TXT             VARCHAR(100),
                LENGTH_OF_SERVICE         VARCHAR(15),
                MANAGER_ID                VARCHAR(32),
                MANAGER_NAME              VARCHAR(101),
                MILITARY_EXPERIENCE_DT    DATE,
                MINORITY_FLG              VARCHAR(1),
                MNMLEV1                   VARCHAR(101),
                MNMLEV2                   VARCHAR(101),
                MNMLEV3                   VARCHAR(101),
                MNMLEV4                   VARCHAR(101),
                MNMLEV5                   VARCHAR(101),
                OVER40                    VARCHAR(1),
                PERMANENCE_CD             VARCHAR(10),
                POSITION_CD               VARCHAR(10),
                QTR                       NUMERIC(8),
                SERVICE_START_DT          DATE,
                SERVICE_YEARS             NUMERIC(8),
                STATE_REGION_CD           VARCHAR(10),
                STECLASS                  VARCHAR(10),
                WKDAY                     NUMERIC(8),
                _LASTREC                  VARCHAR(1)
                ) TYPE=InnoDB
        ) by PASSTHRU;


execute(
         CREATE TABLE  ACTHIST (
             ACTION_TYPE_CD             VARCHAR(10)        ,
             EMPLOYEE_ACTION_REASON_CD  VARCHAR(10)        ,
             EMPLOYEE_ID                VARCHAR(32)        ,
             EMPLOYEE_PAID_FREQUENCY_CD VARCHAR(3)         ,
             EMPLOYEE_STATUS_CD         VARCHAR(3)         ,
             DISCIPLINARY_ACTION_FLG    VARCHAR(1)         ,
             FLSA_STATUS_CD             VARCHAR(1)         ,
             EMPLOYEE_TYPE_CD           VARCHAR(10)        ,
             EXEMPT_STATUS_CD           VARCHAR(10)        ,
             EVALUATION_RESULT_CD       VARCHAR(10)        ,
             INTORG_HR                  VARCHAR(32)        ,
             INTORG_MGR                 VARCHAR(32)        ,
             JOB_CD                     VARCHAR(10)        ,
             PAY_FREQUENCY_CD           VARCHAR(3)         ,
             PAY_LEVEL_STRUCTURE_CD     VARCHAR(20)        ,
             PERMANENCE_CD              VARCHAR(10)        ,
             POSITION_CD                VARCHAR(10)        ,
             ONPAYRL                    VARCHAR(1)         ,
             EMPLOYEE_RK                NUMERIC(8)         ,
             ANNUAL_SALARY              NUMERIC(8)         ,
             FTE_RT                     NUMERIC(8)         ,
             HOURS_PER_WEEK_CNT         NUMERIC(2)         ,
             MONTHLY_SALARY             NUMERIC(8)         ,
             HOURLY_SALARY              NUMERIC(8)         ,
             _LASTREC                   VARCHAR(1)         ,
             ACTION_DT                  DATE               ,
             VALID_TO_DT              DATE
                ) TYPE=InnoDB
        ) by PASSTHRU;


execute(
         CREATE TABLE  ACTHMAST (
            ACTIONS                     NUMERIC(8),
            ACTION_DT                   DATE,
            ACTION_MONTH                NUMERIC(8),
            ACTION_TYPE_CD              VARCHAR(10),
            ACTION_YEAR                 NUMERIC(8),
            AGE                         NUMERIC(8),
            AGE_RANGE                   VARCHAR(15),
            AMT_OVER_MAXIMUM            NUMERIC(8),
            AMT_UNDER_MINIMUM           NUMERIC(8),
            ANNUAL_SALARY               NUMERIC(8),
            BIRTH_DT                    DATE,
            CITY_NM                     VARCHAR(100),
            COMRATIO                    NUMERIC(8),
            CURRENCY_CD                 VARCHAR(3),
            DATE_IN_GRADE               DATE,
            DATE_IN_JOB                 DATE,
            DISABILITY_FLG              VARCHAR(1),
            DISCIPLINARY_ACTION_FLG     VARCHAR(1),
            EEO_CLASS_CD                VARCHAR(10),
            EMPLOYEE_ACTION_REASON_CD   VARCHAR(10),
            EMPLOYEE_ID                 VARCHAR(32),
            EMPLOYEE_NAME               VARCHAR(60),
            EMPLOYEE_NO                 VARCHAR(20),
            EMPLOYEE_PAID_FREQUENCY_CD  VARCHAR(3),
            EMPLOYEE_STATUS_CD          VARCHAR(10),
            EMPLOYEE_TYPE_CD            VARCHAR(10),
            ETHNICITY_CD                VARCHAR(10),
            EVALUATION_RESULT_CD        VARCHAR(10),
            EXEMPT_STATUS_CD            VARCHAR(10),
            FLSA_STATUS_CD              VARCHAR(10),
            FTEQUIV                     NUMERIC(8),
            FTE_RT                      NUMERIC(8),
            GENDER_CD                   VARCHAR(3),
            HIRE_DT                     NUMERIC(8),
            HOURLY_SALARY               NUMERIC(8),
            HOURS_PER_WEEK_CNT          NUMERIC(8),
            INTERNAL_ORG_ID             VARCHAR(32),
            INTORG_HR                   VARCHAR(32),
            INTORG_HR1                  VARCHAR(32),
            INTORG_HR2                  VARCHAR(32),
            INTORG_HR3                  VARCHAR(32),
            INTORG_HR4                  VARCHAR(32),
            INTORG_HR5                  VARCHAR(32),
            INTORG_MGR                  VARCHAR(32),
            INTORG_MGR1                 VARCHAR(32),
            INTORG_MGR2                 VARCHAR(32),
            INTORG_MGR3                 VARCHAR(32),
            INTORG_MGR4                 VARCHAR(32),
            INTORG_MGR5                 VARCHAR(32),
            JOB_CD                      VARCHAR(10),
            JOB_GROUP_CD                VARCHAR(10),
            JOB_GROUP_DESC              VARCHAR(255),
            JOB_TITLE_TXT               VARCHAR(100),
            LENGTH_OF_SERVICE           VARCHAR(15),
            MANAGER_ID                  VARCHAR(32),
            MANAGER_NAME                VARCHAR(101),
            MAXIMUM_AMT                 NUMERIC(8),
            MIDPOINT_AMT                NUMERIC(8),
            MILITARY_EXPERIENCE_DT      DATE,
            MINIMUM_AMT                 NUMERIC(8),
            MINORITY_FLG                VARCHAR(1),
            MNMLEV1                     VARCHAR(101),
            MNMLEV2                     VARCHAR(101),
            MNMLEV3                     VARCHAR(101),
            MNMLEV4                     VARCHAR(101),
            MNMLEV5                     VARCHAR(101),
            MONTHLY_SALARY              NUMERIC(8),
            ONPAYRL                     VARCHAR(1),
            OVER40                      VARCHAR(1),
            PAY_FREQUENCY_CD            VARCHAR(3),
            PAY_GRADE_FREQUENCY_CD      VARCHAR(3),
            PAY_LEVEL_CD                VARCHAR(20),
            PAY_LEVEL_STRUCTURE_CD      VARCHAR(20),
            PAY_LEVEL_TYPE              VARCHAR(25),
            PCT_OVER_MAXIMUM            NUMERIC(8),
            PCT_UNDER_MINIMUM           NUMERIC(8),
            PERMANENCE_CD               VARCHAR(10),
            POSITION_CD                 VARCHAR(10),
            QTR                         NUMERIC(8),
            RNG_PENE                    NUMERIC(8),
            SERVICE_START_DT            DATE,
            SERVICE_YEARS               NUMERIC(8),
            STATE_REGION_CD             VARCHAR(10),
            STECLASS                    VARCHAR(10),
            VALID_TO_DT                 DATE,
            _LASTREC                    VARCHAR(1)

                ) TYPE=InnoDB
        ) by PASSTHRU;


execute(
         CREATE TABLE  APPHIST (
             EMPLOYMENT_APPLICATION_ID           VARCHAR(32)        ,
             POSITION_CD                         VARCHAR(10)        ,
             APPLICATION_DT                      DATE               ,
             EMPLOYEE_ID                         VARCHAR(32)        ,
             APPLICATION_STATUS_CD               VARCHAR(10)        ,
             APPLICANT_INTERVIEWED_FLG           VARCHAR(1)         ,
             RECRUITMENT_SOURCE_CD               VARCHAR(10)        ,
             APPLICANT_NAME                      VARCHAR(40)        ,
             APPLICANT_STATE_REGION_CD           VARCHAR(10)        ,
             APPLICANT_CITY_NM                   VARCHAR(100)       ,
             APPLICANT_POSTAL_CD                 VARCHAR(20)        ,
             APPLICANT_COUNTRY_CD                VARCHAR(3)         ,
             APPLICANT_GENDER_CD                 VARCHAR(3)         ,
             REJECTION_REASON_CD                 VARCHAR(6)         ,
             APPLICANT_BIRTH_DT                   DATE              ,
             APPLICANT_ETHNICITY_CD              VARCHAR(10)        ,
             APPLICANT_SOCIAL_SECURITY_NO        VARCHAR(20)        ,
             APPLICANT_COUNTY_NM                 VARCHAR(50)
                ) TYPE=InnoDB
        ) by PASSTHRU;


execute(
         CREATE TABLE  APPHMAST (
               APPAGE                        NUMERIC(8),
               APPLICANT_BIRTH_DT            DATE,
               APPLICANT_CITY_NM             VARCHAR(100),
               APPLICANT_COUNTRY_CD          VARCHAR(3),
               APPLICANT_COUNTY_NM           VARCHAR(50),
               APPLICANT_ETHNICITY_CD        VARCHAR(10),
               APPLICANT_GENDER_CD           VARCHAR(3),
               APPLICANT_INTERVIEWED_FLG     VARCHAR(1),
               APPLICANT_NAME                VARCHAR(40),
               APPLICANT_POSTAL_CD           VARCHAR(20),
               APPLICANT_SOCIAL_SECURITY_NO  VARCHAR(20),
               APPLICANT_STATE_REGION_CD     VARCHAR(10),
               APPLICATION_DT                NUMERIC(8),
               APPLICATION_MONTH             NUMERIC(8),
               APPLICATION_STATUS_CD         VARCHAR(10),
               APPLICATION_YEAR              NUMERIC(8),
               APPOV40                       VARCHAR(1),
               CNT                           NUMERIC(8),
               EEO_CLASS_CD                  VARCHAR(10),
               EMPLOYEE_ID                   VARCHAR(32),
               EMPLOYMENT_APPLICATION_ID     VARCHAR(32),
               EXEMPT_STATUS_CD              VARCHAR(10),
               INTERNAL_ORG_ID               VARCHAR(32),
               INTORG_HR1                    VARCHAR(32),
               INTORG_HR2                    VARCHAR(32),
               INTORG_HR3                    VARCHAR(32),
               INTORG_HR4                    VARCHAR(32),
               INTORG_HR5                    VARCHAR(32),
               JOB_CD                        VARCHAR(10),
               JOB_GROUP_CD                  VARCHAR(10),
               JOB_GROUP_DESC                VARCHAR(255),
               JOB_TITLE_TXT                 VARCHAR(100),
               MANAGER_ID                    VARCHAR(32),
               MANAGER_NAME                  VARCHAR(101),
               MNMLEV1                       VARCHAR(101),
               MNMLEV2                       VARCHAR(101),
               MNMLEV3                       VARCHAR(101),
               MNMLEV4                       VARCHAR(101),
               MNMLEV5                       VARCHAR(101),
               PERMANENCE_CD                 VARCHAR(10),
               POSITION_CD                   VARCHAR(10),
               QTR                           NUMERIC(8),
               RECRUITMENT_SOURCE_CD         VARCHAR(10),
               REJECTION_REASON_CD           VARCHAR(6),
               STECLASS                      VARCHAR(10),
               VALID_TO_DT                   NUMERIC(8),
               _LASTREC                      VARCHAR(1)
               ) TYPE=InnoDB
        ) by PASSTHRU;



execute(
         CREATE TABLE  CGRADE (
             PAY_LEVEL_CD                 VARCHAR(20)             ,
             PAY_LEVEL_STRUCTURE_CD       VARCHAR(20)             ,
             VALID_FROM_DT                DATE                    ,
             VALID_TO_DT                  DATE                    ,
             MINIMUM_AMT                  NUMERIC(10,2)           ,
             MIDPOINT_AMT                 NUMERIC(10,2)           ,
             MAXIMUM_AMT                  NUMERIC(10,2)           ,
             PAY_GRADE_FREQUENCY_CD       VARCHAR(3)              ,
             PAY_LEVEL_DESC               VARCHAR(255)            ,
             PAY_LEVEL_TYPE               VARCHAR(25)             ,
             ACTIVE_FLG                   VARCHAR(1)              ,
             MIDPOINT_DIFF                NUMERIC(8)              ,
             RANGE_SPREAD                 NUMERIC(8)
                ) TYPE=InnoDB
        ) by PASSTHRU;

execute(
         CREATE TABLE  CHURN (
            ACTIONS                     NUMERIC(8)   ,
            ACTION_DT                   NUMERIC(8)   ,
            ACTION_MONTH                NUMERIC(8)   ,
            ACTION_TYPE_CD              VARCHAR(10)  ,
            ACTION_YEAR                 NUMERIC(8)   ,
            AGE                         NUMERIC(8)   ,
            AGE_RANGE                   VARCHAR(15)  ,
            AMT_OVER_MAXIMUM            NUMERIC(8)   ,
            AMT_UNDER_MINIMUM           NUMERIC(8)   ,
            ANNUAL_SALARY               NUMERIC(8)   ,
            BIRTH_DT                    NUMERIC(8)   ,
            CITY_NM                     VARCHAR(100) ,
            COMRATIO                    NUMERIC(8)   ,
            CURRENCY_CD                 VARCHAR(3)   ,
            DATE_IN_GRADE               NUMERIC(8)   ,
            DATE_IN_JOB                 NUMERIC(8)   ,
            DISABILITY_FLG              VARCHAR(1)   ,
            DISCIPLINARY_ACTION_FLG     VARCHAR(1)   ,
            EEO_CLASS_CD                VARCHAR(10)   ,
            EMPLOYEE_ACTION_REASON_CD   VARCHAR(10)  ,
            EMPLOYEE_ID                 VARCHAR(32)  ,
            EMPLOYEE_NAME               VARCHAR(60)  ,
            EMPLOYEE_NO                 VARCHAR(20)  ,
            EMPLOYEE_PAID_FREQUENCY_CD  VARCHAR(3)   ,
            EMPLOYEE_STATUS_CD          VARCHAR(10)  ,
            EMPLOYEE_TYPE_CD            VARCHAR(10)  ,
            ETHNICITY_CD                VARCHAR(10)   ,
            EVALUATION_RESULT_CD        VARCHAR(10)  ,
            EXEMPT_STATUS_CD            VARCHAR(10)  ,
            FLSA_STATUS_CD              VARCHAR(10)  ,
            FTEQUIV                     NUMERIC(8)   ,
            FTE_RT                      NUMERIC(8)   ,
            GENDER_CD                   VARCHAR(3)   ,
            HIRE_DT                     NUMERIC(8)   ,
            HOURLY_SALARY               NUMERIC(8)   ,
            HOURS_PER_WEEK_CNT          NUMERIC(8)   ,
            INTERNAL_ORG_ID             VARCHAR(32)  ,
            INTORG_HR                   VARCHAR(32)  ,
            INTORG_HR1                  VARCHAR(32)  ,
            INTORG_HR2                  VARCHAR(32)  ,
            INTORG_HR3                  VARCHAR(32)  ,
            INTORG_HR4                  VARCHAR(32)  ,
            INTORG_HR5                  VARCHAR(32)  ,
            INTORG_MGR                  VARCHAR(32)  ,
            INTORG_MGR1                 VARCHAR(32)  ,
            INTORG_MGR2                 VARCHAR(32)  ,
            INTORG_MGR3                 VARCHAR(32)  ,
            INTORG_MGR4                 VARCHAR(32)  ,
            INTORG_MGR5                 VARCHAR(32)  ,
            JOB_CD                      VARCHAR(10)  ,
            JOB_GROUP_CD                VARCHAR(10)  ,
            JOB_GROUP_DESC              VARCHAR(255) ,
            JOB_TITLE_TXT               VARCHAR(100) ,
            LENGTH_OF_SERVICE           VARCHAR(15)  ,
            MANAGER_ID                  VARCHAR(32)  ,
            MANAGER_NAME                VARCHAR(101) ,
            MAXIMUM_AMT                 NUMERIC(8)   ,
            MIDPOINT_AMT                NUMERIC(8)   ,
            MILITARY_EXPERIENCE_DT      NUMERIC(8)   ,
            MINIMUM_AMT                 NUMERIC(8)   ,
            MINORITY_FLG                VARCHAR(1)   ,
            MNMLEV1                     VARCHAR(101) ,
            MNMLEV2                     VARCHAR(101) ,
            MNMLEV3                     VARCHAR(101) ,
            MNMLEV4                     VARCHAR(101) ,
            MNMLEV5                     VARCHAR(101) ,
            MONTHLY_SALARY              NUMERIC(8)   ,
            ONPAYRL                     VARCHAR(1)   ,
            OVER40                      VARCHAR(1)   ,
            PAY_FREQUENCY_CD            VARCHAR(3)   ,
            PAY_LEVEL_CD                VARCHAR(20)  ,
            PAY_LEVEL_STRUCTURE_CD      VARCHAR(20)  ,
            PAY_LEVEL_TYPE              VARCHAR(25)  ,
            PCT_OVER_MAXIMUM            NUMERIC(8)   ,
            PCT_UNDER_MINIMUM           NUMERIC(8)   ,
            PERMANENCE_CD               VARCHAR(10)  ,
            POSITION_CD                 VARCHAR(10)  ,
            QTR                         NUMERIC(8)   ,
            RNG_PENE                    NUMERIC(8)   ,
            SERVICE_START_DT            NUMERIC(8)   ,
            SERVICE_YEARS               NUMERIC(8)   ,
            STATE_REGION_CD             VARCHAR(10)   ,
            STECLASS                    VARCHAR(10)  ,
            VALID_TO_DT                 NUMERIC(8)   ,
            _LASTREC                    VARCHAR(1)
                ) TYPE=InnoDB
        ) by PASSTHRU;


execute(
         CREATE TABLE  CJOBS (
             JOB_CD               VARCHAR(10)             ,
             VALID_FROM_DT      DATE                      ,
             VALID_TO_DT        DATE                      ,
             ACTIVE_FLG           VARCHAR(1)              ,
             JOB_TITLE_TXT        VARCHAR(100)            ,
             JOB_GROUP_CD         VARCHAR(10)             ,
             JOB_GROUP_DESC       VARCHAR(255)            ,
             EEO_CLASS_CD         VARCHAR(10)
                ) TYPE=InnoDB
        ) by PASSTHRU;


execute(
         CREATE TABLE CWRKGRP (
             INTORG               VARCHAR(32)  ,
             PARENT_INTORG        VARCHAR(32)  ,
             GRPDESC              VARCHAR(255) ,
             MANAGER_NAME         VARCHAR(101) ,
             MANAGER_ID           VARCHAR(32)  ,
             HIERARCHY_CD         VARCHAR(32)  ,
             VALID_FROM_DT      DATE           ,
             VALID_TO_DT        DATE
                ) TYPE=InnoDB
        ) by PASSTHRU;


execute(
         CREATE TABLE  COMPHIST (
             EMPLOYEE_ID          VARCHAR(32)         ,
             COMPENSATION_TYPE_CD VARCHAR(10)         ,
             PAYMENT_DT           DATE                ,
             COMPENSATION_AMT     NUMERIC(10,2)
                ) TYPE=InnoDB
        ) by PASSTHRU;


execute(
         CREATE TABLE  EMPMAST (
            ADDRESS_LINE_1_TXT           VARCHAR(100),
            ADDRESS_LINE_2_TXT           VARCHAR(100),
            AGE                          NUMERIC(8),
            AGE_RANGE                    VARCHAR(15),
            AMT_OVER_MAXIMUM             NUMERIC(8),
            AMT_UNDER_MINIMUM            NUMERIC(8),
            ANNUAL_SALARY                NUMERIC(8),
            BIRTH_DT                     DATE,
            CITIZENSHIP_COUNTRY_CD       VARCHAR(3),
            CITY_NM                      VARCHAR(100),
            COMRATIO                     NUMERIC(8),
            COUNTRY_CD                   VARCHAR(3),
            COUNTY_NM                    VARCHAR(50),
            CURRENCY_CD                  VARCHAR(3),
            DISABILITY_FLG               VARCHAR(1),
            DISCIPLINARY_ACTION_FLG      VARCHAR(1),
            EEO_CLASS_CD                 VARCHAR(10),
            EMPLOYEE_ID                  VARCHAR(32) NOT NULL,
            EMPLOYEE_NAME                VARCHAR(60),
            EMPLOYEE_NO                  VARCHAR(20),
            EMPLOYEE_PAID_FREQUENCY_CD   VARCHAR(3),
            EMPLOYEE_STATUS_CD           VARCHAR(10),
            EMPLOYEE_TYPE_CD             VARCHAR(10),
            ETHNICITY_CD                 VARCHAR(10),
            EVALUATION_RESULT_CD         VARCHAR(10),
            EXEMPT_STATUS_CD             VARCHAR(10),
            FLSA_STATUS_CD               VARCHAR(10),
            FTEQUIV                      NUMERIC(8),
            FTE_RT                       NUMERIC(8),
            GENDER_CD                    VARCHAR(3),
            HIRE_DT                      DATE,
            HOURLY_SALARY                NUMERIC(8),
            HOURS_PER_WEEK_CNT           NUMERIC(8),
            INTORG_HR                    VARCHAR(32),
            INTORG_HR1                   VARCHAR(32),
            INTORG_HR2                   VARCHAR(32),
            INTORG_HR3                   VARCHAR(32),
            INTORG_HR4                   VARCHAR(32),
            INTORG_HR5                   VARCHAR(32),
            INTORG_MGR                   VARCHAR(32),
            INTORG_MGR1                  VARCHAR(32),
            INTORG_MGR2                  VARCHAR(32),
            INTORG_MGR3                  VARCHAR(32),
            INTORG_MGR4                  VARCHAR(32),
            INTORG_MGR5                  VARCHAR(32),
            JOB_CD                       VARCHAR(10),
            JOB_GROUP_CD                 VARCHAR(10),
            JOB_GROUP_DESC               VARCHAR(255),
            JOB_TITLE_TXT                VARCHAR(100),
            LENGTH_OF_SERVICE            VARCHAR(15),
            MANAGER_ID                   VARCHAR(32),
            MANAGER_NAME                 VARCHAR(101),
            MARITAL_STATUS_CD            VARCHAR(3),
            MAXIMUM_AMT                  NUMERIC(8),
            MIDPOINT_AMT                 NUMERIC(8),
            MILITARY_EXPERIENCE_DT       DATE,
            MILITARY_EXPERIENCE_TYPE_CD  VARCHAR(10),
            MINIMUM_AMT                  NUMERIC(8),
            MINORITY_FLG                 VARCHAR(1),
            MNMLEV1                      VARCHAR(101),
            MNMLEV2                      VARCHAR(101),
            MNMLEV3                      VARCHAR(101),
            MNMLEV4                      VARCHAR(101),
            MNMLEV5                      VARCHAR(101),
            MONTHLY_SALARY               NUMERIC(8),
            ONPAYRL                      VARCHAR(1),
            OVER40                       VARCHAR(1),
            PAY_FREQUENCY_CD             VARCHAR(3),
            PAY_GRADE_FREQUENCY_CD       VARCHAR(3),
            PAY_LEVEL_CD                 VARCHAR(20),
            PAY_LEVEL_STRUCTURE_CD       VARCHAR(20),
            PAY_LEVEL_TYPE               VARCHAR(25),
            PCT_OVER_MAXIMUM             NUMERIC(8),
            PCT_UNDER_MINIMUM            NUMERIC(8),
            PERMANENCE_CD                VARCHAR(10),
            POSITION_CD                  VARCHAR(10),
            POSTAL_CD                    VARCHAR(20),
            RNG_PENE                     NUMERIC(8),
            SERVICE_START_DT             DATE,
            SERVICE_YEARS                NUMERIC(8),
            SOCIAL_SECURITY_NO           VARCHAR(20),
            STATE_REGION_CD              VARCHAR(10),
            STECLASS                     VARCHAR(10),
            UNION_CD                     VARCHAR(10),
            VALID_FROM_DT                DATE,
            VALID_TO_DT                  DATE,
            _LASTREC                     VARCHAR(1)
             ) TYPE=InnoDB
        ) by PASSTHRU;



execute(
         CREATE TABLE  EMPGEN (
             EMPLOYEE_NAME        VARCHAR(60)        ,
             VALID_FROM_DT      DATE                 ,
             VALID_TO_DT        DATE                 ,
             EMPLOYEE_ID          VARCHAR(32)        ,
             ADDRESS_LINE_1_TXT   VARCHAR(100)       ,
             ADDRESS_LINE_2_TXT   VARCHAR(100)       ,
             CITY_NM              VARCHAR(100)       ,
             STATE_REGION_CD      VARCHAR(10)        ,
             COUNTRY_CD           VARCHAR(3)         ,
             CITIZENSHIP_COUNTRY_CD VARCHAR(3)       ,
             ETHNICITY_CD         VARCHAR(10)        ,
             MARITAL_STATUS_CD    VARCHAR(3)         ,
             GENDER_CD            VARCHAR(3)         ,
             UNION_CD             VARCHAR(10)        ,
             MINORITY_FLG         VARCHAR(1)         ,
             SOCIAL_SECURITY_NO   VARCHAR(20)        ,
             COUNTY_NM            VARCHAR(50)        ,
             POSTAL_CD            VARCHAR(20)        ,
             HIRE_DT              DATE               ,
             SERVICE_START_DT     DATE               ,
             EMPLOYEE_NO          VARCHAR(20)        ,
             BIRTH_DT             DATE               ,
             DISABILITY_FLG       VARCHAR(1)         ,
             MILITARY_EXPERIENCE_TYPE_CD VARCHAR(10) ,
             MILITARY_EXPERIENCE_DT DATE
                ) TYPE=InnoDB
        ) by PASSTHRU;


execute(
         CREATE TABLE  FACTORSITE (
             VALID_DT          DATE         ,
             MEASURE_NM        VARCHAR(100) ,
             MEASURE_VALUE_NO  NUMERIC(10)  ,
             MEASURE_DESC      VARCHAR(100)
                ) TYPE=InnoDB
        ) by PASSTHRU;


execute(
         CREATE TABLE  GRADE (
             PAY_LEVEL_CD            VARCHAR(20)   ,
             PAY_LEVEL_STRUCTURE_CD  VARCHAR(20)   ,
             VALID_FROM_DT           DATE          ,
             VALID_TO_DT             DATE          ,
             MINIMUM_AMT             NUMERIC(10,2) ,
             MIDPOINT_AMT            NUMERIC(10,2) ,
             MAXIMUM_AMT             NUMERIC(10,2) ,
             PAY_GRADE_FREQUENCY_CD  VARCHAR(3)    ,
             PAY_LEVEL_DESC          VARCHAR(255)  ,
             PAY_LEVEL_TYPE          VARCHAR(25)   ,
             ACTIVE_FLG              VARCHAR(1)
                ) TYPE=InnoDB
        ) by PASSTHRU;


execute(
         CREATE TABLE HCBNCHMRK (
              ELEMENT_BOOK_NM     VARCHAR(255)    ,
              SECTION_DS          VARCHAR(100)    ,
              STAT_TYPE_DS        VARCHAR(30)     ,
              STAT_DS             VARCHAR(100)    ,
              PERIOD_DS           VARCHAR(100)    ,
              PERIOD_YEAR_NUM     NUMERIC         ,
              P10_VAL             NUMERIC(10,2)   ,
              P25_VAL             NUMERIC(10,2)   ,
              MEDIAN_VAL          NUMERIC(10,2)   ,
              P75_VAL             NUMERIC(10,2)   ,
              P90_VAL             NUMERIC(10,2)   ,
              MEAN_VAL            NUMERIC(10,2)   ,
              FORMAT_DS           VARCHAR(100)    ,
              ELEMENT_ID          VARCHAR(11)
                ) TYPE=InnoDB
        ) by PASSTHRU;


execute(
         CREATE TABLE HCMFORMATS (
          FMTNAME         VARCHAR(9),
          FMTSTART        VARCHAR(40),
          FMTEND        VARCHAR(40),
          FMTVALUE      VARCHAR(128)
                  ) TYPE=InnoDB
       ) by PASSTHRU;


execute(
         CREATE TABLE  HEADSUM (
           AVGTURN             NUMERIC(8),
           CHURN               NUMERIC(8),
           DPRO                NUMERIC(8),
           EEO_CLASS_CD        VARCHAR(10),
           EMPLOYEE_ID         VARCHAR(32),
           EMPLOYEE_TYPE_CD    VARCHAR(10),
           ETHNICITY_CD        VARCHAR(10),
           EXEMPT_STATUS_CD    VARCHAR(10),
           FTECNT              NUMERIC(8),
           FTEDIF              NUMERIC(8),
           FTEGROW             NUMERIC(8),
           GENDER_CD           VARCHAR(3),
           GROWTH              NUMERIC(8),
           HDDIF               NUMERIC(8),
           HEADCNT             NUMERIC(8),
           INTORG_HR           VARCHAR(32),
           INTORG_HR1          VARCHAR(32),
           INTORG_HR2          VARCHAR(32),
           INTORG_HR3          VARCHAR(32),
           INTORG_HR4          VARCHAR(32),
           INTORG_HR5          VARCHAR(32),
           INTORG_MGR          VARCHAR(32),
           INTORG_MGR1         VARCHAR(32),
           INTORG_MGR2         VARCHAR(32),
           INTORG_MGR3         VARCHAR(32),
           INTORG_MGR4         VARCHAR(32),
           INTORG_MGR5         VARCHAR(32),
           ITERM               NUMERIC(8),
           ITERMDIF            NUMERIC(8),
           ITERMSEP            NUMERIC(8),
           NHIREDIF            NUMERIC(8),
           NHIRES              NUMERIC(8),
           PAY                 NUMERIC(8),
           PERMANENCE_CD       VARCHAR(10),
           QTR                 NUMERIC(8),
           TERMDIF             NUMERIC(8),
           TERMS               NUMERIC(8),
           TURNOVER            NUMERIC(8),
           VALID_DT            DATE,
           VALID_MONTH         NUMERIC(8),
           VALID_YEAR          NUMERIC(8),
           VTERM               NUMERIC(8),
           VTERMDIF            NUMERIC(8),
           VTERMSEP            NUMERIC(8),
           _LASTREC            VARCHAR(1)
                ) TYPE=InnoDB
        ) by PASSTHRU;


execute(
         CREATE TABLE  JOBS (
             JOB_CD               VARCHAR(10)  ,
             VALID_FROM_DT        DATE         ,
             VALID_TO_DT          DATE         ,
             ACTIVE_FLG           VARCHAR(1)   ,
             JOB_TITLE_TXT        VARCHAR(100) ,
             JOB_GROUP_CD         VARCHAR(10)  ,
             JOB_GROUP_DESC       VARCHAR(255) ,
             EEO_CLASS_CD         VARCHAR(10)   ,
             STECLASS             VARCHAR(10)
                ) TYPE=InnoDB
        ) by PASSTHRU;


execute(
         CREATE TABLE  OPENPOS (
             POSITION_CD          VARCHAR(10)   ,
             OPEN_DT              DATE          ,
             CLOSE_DT             DATE          ,
             CANCELLATION_DT      DATE          ,
             REQUISITION_COST_AMT NUMERIC(10,2) ,
             REQUISITION_NO       VARCHAR(10)
                ) TYPE=InnoDB
        ) by PASSTHRU;


execute(
         CREATE TABLE  OPOSMAST (
            CANCELLATION_DT         DATE,
            CLOSE_DT                DATE,
            EEO_CLASS_CD            VARCHAR(10),
            EMPLOYEE_ID             VARCHAR(32),
            EXEMPT_STATUS_CD        VARCHAR(10),
            INTERNAL_ORG_ID         VARCHAR(32),
            INTORG_HR1              VARCHAR(32),
            INTORG_HR2              VARCHAR(32),
            INTORG_HR3              VARCHAR(32),
            INTORG_HR4              VARCHAR(32),
            INTORG_HR5              VARCHAR(32),
            JOB_CD                  VARCHAR(10),
            JOB_GROUP_CD            VARCHAR(10),
            JOB_GROUP_DESC          VARCHAR(255),
            JOB_TITLE_TXT           VARCHAR(100),
            MANAGER_ID              VARCHAR(32),
            MANAGER_NAME            VARCHAR(101),
            MNMLEV1                 VARCHAR(101),
            MNMLEV2                 VARCHAR(101),
            MNMLEV3                 VARCHAR(101),
            MNMLEV4                 VARCHAR(101),
            MNMLEV5                 VARCHAR(101),
            OPENTIME                NUMERIC(8),
            OPEN_DT                 DATE,
            OPEN_MONTH              NUMERIC(8),
            OPEN_YEAR               NUMERIC(8),
            PERMANENCE_CD           VARCHAR(10),
            POSITION_CD             VARCHAR(10),
            QTR                     NUMERIC(8),
            REQUISITION_COST_AMT    NUMERIC(8),
            REQUISITION_NO          VARCHAR(10),
            STECLASS                VARCHAR(10),
            _LASTREC                VARCHAR(1)
                ) TYPE=InnoDB
        ) by PASSTHRU;

execute(
         CREATE TABLE  OPOSSUM (
            CNTPCT              NUMERIC(8),
            EEO_CLASS_CD        VARCHAR(10),
            EXEMPT_STATUS_CD    VARCHAR(10),
            INTERNAL_ORG_ID     VARCHAR(32),
            INTORG_HR1          VARCHAR(32),
            INTORG_HR2          VARCHAR(32),
            INTORG_HR3          VARCHAR(32),
            INTORG_HR4          VARCHAR(32),
            INTORG_HR5          VARCHAR(32),
            JOB_CD              VARCHAR(10),
            OPCHGPCT            NUMERIC(8),
            OPDIF               NUMERIC(8),
            OPOSCNT             NUMERIC(8),
            PERMANENCE_CD       VARCHAR(10),
            TOTCNT              NUMERIC(8),
            VALID_DT            DATE
                ) TYPE=InnoDB
        ) by PASSTHRU;



execute(
         CREATE TABLE  POS (
             POSITION_CD          VARCHAR(10)   ,
             EMPLOYEE_ID          VARCHAR(32)   ,
             JOB_CD               VARCHAR(10)   ,
             EXEMPT_STATUS_CD     VARCHAR(10)   ,
             INTERNAL_ORG_ID      VARCHAR(32)   ,
             HRPAYPER             NUMERIC(8)    ,
             PAY_FREQUENCY_CD     VARCHAR(3)    ,
             POS_FTE_RT           NUMERIC(9,4)  ,
             POSITION_STATUS_CD   VARCHAR(10)   ,
             PERMANENCE_CD        VARCHAR(10)   ,
             VALID_FROM_DT      DATE            ,
             VALID_TO_DT        DATE
                ) TYPE=InnoDB
        ) by PASSTHRU;


execute(
         CREATE TABLE  SALHIST (
           ACTION_DT                   DATE,
           ACTION_MONTH                NUMERIC(8),
           ACTION_TYPE_CD              VARCHAR(10),
           ACTION_YEAR                 NUMERIC(8),
           AGE                         NUMERIC(8),
           AGE_RANGE                   VARCHAR(15),
           AMT_OVER_MAXIMUM            NUMERIC(8),
           AMT_UNDER_MINIMUM           NUMERIC(8),
           ANNUAL_SALARY               NUMERIC(8),
           BIRTH_DT                    DATE,
           CHNGEST                     NUMERIC(8),
           CHNGMNTH                    NUMERIC(8),
           CHNGPCT                     NUMERIC(8),
           CHNGSAL                     NUMERIC(8),
           COMRATIO                    NUMERIC(8),
           CURRENCY_CD                 VARCHAR(3),
           DATE_IN_GRADE               DATE,
           DATE_IN_JOB                 DATE,
           DISABILITY_FLG              VARCHAR(1),
           DISCIPLINARY_ACTION_FLG     VARCHAR(1),
           EEO_CLASS_CD                VARCHAR(10),
           EMPLOYEE_ACTION_REASON_CD   VARCHAR(10),
           EMPLOYEE_ID                 VARCHAR(32),
           EMPLOYEE_NAME               VARCHAR(60),
           EMPLOYEE_NO                 VARCHAR(20),
           EMPLOYEE_PAID_FREQUENCY_CD  VARCHAR(3),
           EMPLOYEE_STATUS_CD          VARCHAR(10),
           EMPLOYEE_TYPE_CD            VARCHAR(10),
           ETHNICITY_CD                VARCHAR(10),
           EVALUATION_RESULT_CD        VARCHAR(10),
           EXEMPT_STATUS_CD            VARCHAR(10),
           FLSA_STATUS_CD              VARCHAR(10),
           FTEQUIV                     NUMERIC(8),
           FTE_RT                      NUMERIC(8),
           GENDER_CD                   VARCHAR(3),
           HIRE_DT                     DATE,
           HOURLY_SALARY               NUMERIC(8),
           HOURS_PER_WEEK_CNT          NUMERIC(8),
           INTERNAL_ORG_ID             VARCHAR(32),
           INTORG_HR                   VARCHAR(32),
           INTORG_HR1                  VARCHAR(32),
           INTORG_HR2                  VARCHAR(32),
           INTORG_HR3                  VARCHAR(32),
           INTORG_HR4                  VARCHAR(32),
           INTORG_HR5                  VARCHAR(32),
           INTORG_MGR                  VARCHAR(32),
           INTORG_MGR1                 VARCHAR(32),
           INTORG_MGR2                 VARCHAR(32),
           INTORG_MGR3                 VARCHAR(32),
           INTORG_MGR4                 VARCHAR(32),
           INTORG_MGR5                 VARCHAR(32),
           JOB_CD                      VARCHAR(10),
           JOB_GROUP_CD                VARCHAR(10),
           JOB_GROUP_DESC              VARCHAR(255),
           JOB_TITLE_TXT               VARCHAR(100),
           LENGTH_OF_SERVICE           VARCHAR(15),
           MANAGER_ID                  VARCHAR(32),
           MANAGER_NAME                VARCHAR(101),
           MAXIMUM_AMT                 NUMERIC(8),
           MIDPOINT_AMT                NUMERIC(8),
           MINIMUM_AMT                 NUMERIC(8),
           MINORITY_FLG                VARCHAR(1),
           MNMLEV1                     VARCHAR(101),
           MNMLEV2                     VARCHAR(101),
           MNMLEV3                     VARCHAR(101),
           MNMLEV4                     VARCHAR(101),
           MNMLEV5                     VARCHAR(101),
           MONTHLY_SALARY              NUMERIC(8),
           OLD_EST                     NUMERIC(8),
           OLD_MNTH                    NUMERIC(8),
           OLD_SAL                     NUMERIC(8),
           ONPAYRL                     VARCHAR(1),
           OVER40                      VARCHAR(1),
           PAY_FREQUENCY_CD            VARCHAR(3),
           PAY_GRADE_FREQUENCY_CD      VARCHAR(3),
           PAY_LEVEL_CD                VARCHAR(20),
           PAY_LEVEL_STRUCTURE_CD      VARCHAR(20),
           PAY_LEVEL_TYPE              VARCHAR(25),
           PCT_OVER_MAXIMUM            NUMERIC(8),
           PCT_UNDER_MINIMUM           NUMERIC(8),
           PERMANENCE_CD               VARCHAR(10),
           POSITION_CD                 VARCHAR(10),
           RNG_PENE                    NUMERIC(8),
           SERVICE_START_DT            DATE,
           SERVICE_YEARS               NUMERIC(8),
           STECLASS                    VARCHAR(10),
           _LASTREC                    VARCHAR(1)
                ) TYPE=InnoDB
        ) by PASSTHRU;



execute(
         CREATE TABLE  SALHSUM (
           ADD1                        NUMERIC(8),
           ADD2                        NUMERIC(8),
           ADD3                        NUMERIC(8),
           AGE                         NUMERIC(8),
           AGE_RANGE                   VARCHAR(15),
           ANNUAL_SALARY               NUMERIC(8),
           BIRTH_DT                    DATE,
           CHGAMT                      NUMERIC(8),
           CHGPCT                      NUMERIC(8),
           CITY_NM                     VARCHAR(100),
           CURRENCY_CD                 VARCHAR(3),
           DISABILITY_FLG              VARCHAR(1),
           DISCIPLINARY_ACTION_FLG     VARCHAR(1),
           EEO_CLASS_CD                VARCHAR(3),
           EMPLOYEE_ID                 VARCHAR(32),
           EMPLOYEE_NAME               VARCHAR(60),
           EMPLOYEE_NO                 VARCHAR(20),
           EMPLOYEE_PAID_FREQUENCY_CD  VARCHAR(3),
           EMPLOYEE_STATUS_CD          VARCHAR(10),
           EMPLOYEE_TYPE_CD            VARCHAR(10),
           ETHNICITY_CD                VARCHAR(10),
           EVALUATION_RESULT_CD        VARCHAR(10),
           EXEMPT_STATUS_CD            VARCHAR(10),
           FLSA_STATUS_CD              VARCHAR(10),
           FTE_RT                      NUMERIC(8),
           GENDER_CD                   VARCHAR(3),
           HIRE_DT                     DATE,
           HOURLY_SALARY               NUMERIC(8),
           HOURS_PER_WEEK_CNT          NUMERIC(8),
           INTERNAL_ORG_ID             VARCHAR(32),
           INTORG_HR                   VARCHAR(32),
           INTORG_HR1                  VARCHAR(32),
           INTORG_HR2                  VARCHAR(32),
           INTORG_HR3                  VARCHAR(32),
           INTORG_HR4                  VARCHAR(32),
           INTORG_HR5                  VARCHAR(32),
           INTORG_MGR                  VARCHAR(32),
           INTORG_MGR1                 VARCHAR(32),
           INTORG_MGR2                 VARCHAR(32),
           INTORG_MGR3                 VARCHAR(32),
           INTORG_MGR4                 VARCHAR(32),
           INTORG_MGR5                 VARCHAR(32),
           JOB_CD                      VARCHAR(10),
           JOB_GROUP_CD                VARCHAR(10),
           JOB_GROUP_DESC              VARCHAR(255),
           JOB_TITLE_TXT               VARCHAR(100),
           LENGTH_OF_SERVICE           VARCHAR(15),
           MANAGER_ID                  VARCHAR(32),
           MANAGER_NAME                VARCHAR(101),
           MAXIMUM_AMT                 NUMERIC(8),
           MIDPOINT_AMT                NUMERIC(8),
           MILITARY_EXPERIENCE_DT      DATE,
           MINIMUM_AMT                 NUMERIC(8),
           MINORITY_FLG                VARCHAR(1),
           MNMLEV1                     VARCHAR(101),
           MNMLEV2                     VARCHAR(101),
           MNMLEV3                     VARCHAR(101),
           MNMLEV4                     VARCHAR(101),
           MNMLEV5                     VARCHAR(101),
           MONTHLY_SALARY              NUMERIC(8),
           ONPAYRL                     VARCHAR(1),
           OVER40                      VARCHAR(1),
           PAY_FREQUENCY_CD            VARCHAR(3),
           PAY_GRADE_FREQUENCY_CD      VARCHAR(3),
           PAY_LEVEL_CD                VARCHAR(20),
           PAY_LEVEL_STRUCTURE_CD      VARCHAR(20),
           PAY_LEVEL_TYPE              VARCHAR(25),
           PERMANENCE_CD               VARCHAR(10),
           POSITION_CD                 VARCHAR(10),
           SERVICE_START_DT            DATE,
           SERVICE_YEARS               NUMERIC(8),
           STATE_REGION_CD             VARCHAR(10),
           STECLASS                    VARCHAR(10),
           TOTCOMP                     NUMERIC(8),
           TOTOTHER                    NUMERIC(8),
           VALID_DT                    DATE,
           _LASTREC                    VARCHAR(1)

                ) TYPE=InnoDB
        ) by PASSTHRU;


execute(
         CREATE TABLE  TERMMAST (
           ACTION_DT                   NUMERIC(8),
           ACTION_MONTH                NUMERIC(8),
           ACTION_TYPE_CD              VARCHAR(10),
           ACTION_YEAR                 NUMERIC(8),
           AGE                         NUMERIC(8),
           ANNUAL_SALARY               NUMERIC(8),
           DISABILITY_FLG              VARCHAR(1),
           DISCIPLINARY_ACTION_FLG     VARCHAR(1),
           EEO_CLASS_CD                VARCHAR(10),
           EMPLOYEE_ACTION_REASON_CD   VARCHAR(10),
           EMPLOYEE_ID                 VARCHAR(32),
           EMPLOYEE_NAME               VARCHAR(60),
           EMPLOYEE_TYPE_CD            VARCHAR(10),
           ETHNICITY_CD                VARCHAR(10),
           EXEMPT_STATUS_CD            VARCHAR(10),
           GENDER_CD                   VARCHAR(3),
           HIRE_DT                     DATE,
           HOURLY_SALARY               NUMERIC(8),
           INTORG_HR                   VARCHAR(32),
           INTORG_HR1                  VARCHAR(32),
           INTORG_HR2                  VARCHAR(32),
           INTORG_HR3                  VARCHAR(32),
           INTORG_HR4                  VARCHAR(32),
           INTORG_HR5                  VARCHAR(32),
           INTORG_MGR                  VARCHAR(32),
           INTORG_MGR1                 VARCHAR(32),
           INTORG_MGR2                 VARCHAR(32),
           INTORG_MGR3                 VARCHAR(32),
           INTORG_MGR4                 VARCHAR(32),
           INTORG_MGR5                 VARCHAR(32),
           JOB_GROUP_CD                VARCHAR(10),
           JOB_TITLE_TXT               VARCHAR(100),
           MNMLEV1                     VARCHAR(101),
           MNMLEV2                     VARCHAR(101),
           MNMLEV3                     VARCHAR(101),
           MNMLEV4                     VARCHAR(101),
           MNMLEV5                     VARCHAR(101),
           MONTHLY_SALARY              NUMERIC(8),
           PERMANENCE_CD               VARCHAR(10),
           QTR                         NUMERIC(8),
           SERVICE_START_DT            DATE,
           SERVICE_YEARS               NUMERIC(8),
           YEARMON                     VARCHAR(7),
           _LASTREC                    VARCHAR(1)
              ) TYPE=InnoDB
        ) by PASSTHRU;

execute(
         CREATE TABLE  TIP (
           AGE                 NUMERIC(8),
           EEO_CLASS_CD        VARCHAR(10),
           EMPLOYEE_ID         VARCHAR(32),
           ETHNICITY_CD        VARCHAR(10),
           EXEMPT_STATUS_CD    VARCHAR(10),
           GENDER_CD           VARCHAR(3),
           INTORG_HR           VARCHAR(32),
           INTORG_HR1          VARCHAR(32),
           INTORG_HR2          VARCHAR(32),
           INTORG_HR3          VARCHAR(32),
           INTORG_HR4          VARCHAR(32),
           INTORG_HR5          VARCHAR(32),
           INTORG_MGR          VARCHAR(32),
           INTORG_MGR1         VARCHAR(32),
           INTORG_MGR2         VARCHAR(32),
           INTORG_MGR3         VARCHAR(32),
           INTORG_MGR4         VARCHAR(32),
           INTORG_MGR5         VARCHAR(32),
           JOB_CD              VARCHAR(10),
           JOB_GROUP_CD        VARCHAR(10),
           PERMANENCE_CD       VARCHAR(10),
           TIP_DAYS            NUMERIC(8),
           TIP_MONTHS          NUMERIC(8),
           TIP_YEARS           NUMERIC(8),
           VALID_FROM_DT       NUMERIC(8),
           VALID_TO_DT         DATE
                ) TYPE=InnoDB
        ) by PASSTHRU;

execute(
         CREATE TABLE  USEREMPLOYEE (
             USER_ID               VARCHAR(60)  ,
             EMPLOYEE_ID          VARCHAR(32)
             ) TYPE=InnoDB
        ) by PASSTHRU;

execute(
         CREATE TABLE  WRKGRP (
             INTORG               VARCHAR(32)  ,
             PARENT_INTORG        VARCHAR(32)  ,
             GRPDESC              VARCHAR(255) ,
             MANAGER_NAME         VARCHAR(101) ,
             MANAGER_ID           VARCHAR(32)  ,
             HIERARCHY_CD         VARCHAR(32)  ,
             _LASTREC             VARCHAR(1)   ,
             VALID_FROM_DT      DATE           ,
             VALID_TO_DT        DATE
                ) TYPE=InnoDB
        ) by PASSTHRU;


execute(
         CREATE TABLE EMPLOYEE_PROFILE (
          PROFILEID VARCHAR(36) ,
          PROFILE_NAME VARCHAR(60) ,
          DATASOURCE VARCHAR(32) ,
          KEYATTR VARCHAR(60) ,
          PROFILE_LABEL VARCHAR(60),
          DESCRIPTION VARCHAR(100),
          ADVSEARCHSTATUS smallint,
          IDENTIFIER VARCHAR(60),
          LINKATTR VARCHAR(60),
          STYLESHEET VARCHAR(60),
          LSTYLE VARCHAR(60),
          DSTYLE VARCHAR(60),
          CONSTRAINT EMPLOYEE_PROFILE_PK PRIMARY KEY  (PROFILEID)
                ) TYPE=InnoDB
        ) by PASSTHRU;


execute(
         CREATE TABLE  PROFILEHEADERATTR (
          PROFILEID VARCHAR(36) NOT NULL,
          HEADERATTRID VARCHAR(36) NOT NULL,
          ATTRIBUTEVALUE VARCHAR(60) NOT NULL,
          DATASOURCE VARCHAR(36),
          LSTYLE VARCHAR(60),
          DSTYLE VARCHAR(60),
          CONSTRAINT PROFILEHEADERATTR_PK PRIMARY KEY (PROFILEID, HEADERATTRID)
                ) TYPE=InnoDB
        ) by PASSTHRU;


execute(
         CREATE TABLE  PROFILESEARCHATTR (
          PROFILEID VARCHAR(36) NOT NULL,
          SEARCHATTRID VARCHAR(36) NOT NULL,
          ATTRIBUTEVALUE VARCHAR(60) NOT NULL,
          LSTYLE VARCHAR(60),
          DSTYLE VARCHAR(60),
          CONSTRAINT PROFILESEARCHATTR_PK PRIMARY KEY  (PROFILEID,SEARCHATTRID)
                ) TYPE=InnoDB
        ) by PASSTHRU;



execute(
         CREATE TABLE  PROFILECATEGORY (
          PROFILEID VARCHAR(36) NOT NULL,
          CATEGORYID VARCHAR(36) NOT NULL,
          CATEGORYTYPE VARCHAR(36) NOT NULL,
          CATEGORYLABEL VARCHAR(36) NOT NULL,
          DATASOURCE VARCHAR(36),
          LSTYLE VARCHAR(60),
          DSTYLE VARCHAR(60),
          CONSTRAINT PROFILECATEGORY_PK PRIMARY KEY (PROFILEID, CATEGORYID)
                ) TYPE=InnoDB
        ) by PASSTHRU;


execute(
         CREATE TABLE  PROFILECATEGORYATTR (
          PROFILEID VARCHAR(36)  NOT NULL,
          CATEGORYID VARCHAR(36) NOT NULL,
          CATEGORYATTRID VARCHAR(36)  NOT NULL,
          ATTRIBUTEVALUE VARCHAR(60) NOT NULL,
          DATASOURCE VARCHAR(36),
          LSTYLE VARCHAR(60),
          DSTYLE VARCHAR(60),
          CONSTRAINT PROFILECATEGORYATTR_PK PRIMARY KEY (PROFILEID,CATEGORYID,CATEGORYATTRID)
                ) TYPE=InnoDB
        ) by PASSTHRU;


execute(
         CREATE TABLE  PROFILESUMMARYATTR (
          PROFILEID VARCHAR(36) NOT NULL,
          SUMMARYATTRID VARCHAR(36) NOT NULL,
          ATTRIBUTEVALUE VARCHAR(60) NOT NULL,
          ATTRIBUTETABLE VARCHAR(36),
          LSTYLE VARCHAR(60),
          DSTYLE VARCHAR(60),
          CONSTRAINT PROFILESUMMARYATTR_PK PRIMARY KEY (PROFILEID, SUMMARYATTRID)
                ) TYPE=InnoDB
        ) by PASSTHRU;



execute(
         CREATE TABLE  PROFILETABLEATTR (
          PROFILEID VARCHAR(36) NOT NULL,
          USERID VARCHAR(36) NOT NULL,
          TABLEID VARCHAR(36) NOT NULL,
          DATASOURCE VARCHAR(36) NOT NULL,
          MODELID VARCHAR(36) NOT NULL,
          MENULABEL VARCHAR(36),
          DESCRIPTION VARCHAR (60),
          CONSTRAINT PROFILETABLE_PK PRIMARY KEY (PROFILEID, USERID, TABLEID)
                ) TYPE=InnoDB
        ) by PASSTHRU;


execute(
         CREATE TABLE HIERARCHYMAPPING (
          HIERARCHY_CODE VARCHAR(32) NOT NULL,
          SRCTYPE NUMERIC(8) NOT NULL,
          INFOTABLENAME VARCHAR(60) NOT NULL,
          INFOTABLELINKFIELD VARCHAR(60) NOT NULL,
          ISDEFAULTASSOCTABLE VARCHAR(3) NOT NULL,
          DETAILDIRECTIVE VARCHAR(255),
          CONSTRAINT HIERARCHYMAPPING_PK PRIMARY KEY (HIERARCHY_CODE , SRCTYPE, INFOTABLENAME)
                ) TYPE=InnoDB
        ) by PASSTHRU;

execute(
         CREATE TABLE WRKGRPHIER (
          HIER_EXTERNAL_RK NUMERIC(8),
          ISDEFAULT NUMERIC(8) NOT NULL,
          HIERARCHYCODE  VARCHAR(32) NOT NULL,
          HIERARCHYNAME  VARCHAR(50) ,
          HIERARCHYDESC  VARCHAR(255) ,
          CONSTRAINT WRKGRPHIER_PK PRIMARY KEY (HIERARCHYCODE)
                ) TYPE=InnoDB
        ) by PASSTHRU;


execute(
         CREATE TABLE EXCLUSIONLIST (
          MODULETYPE VARCHAR(10) NOT NULL,
          TABLENAME VARCHAR(60) NOT NULL,
          COLUMNNAME VARCHAR(60) NOT NULL,
          DATA_TYPE NUMERIC(8) NOT NULL,
          CONSTRAINT EXCLUSIONLIST_PK PRIMARY KEY (MODULETYPE, TABLENAME, COLUMNNAME, DATA_TYPE)
                ) TYPE=InnoDB
        ) by PASSTHRU;


execute(
         CREATE TABLE DEFAULTPROPERTIES (
          MODULETYPE VARCHAR(10) NOT NULL,
          DATA_TYPE NUMERIC(8) NOT NULL,
          PROPERTYNAME VARCHAR(60) NOT NULL,
          DEFAULTVALUE VARCHAR(255),
          DESCRIPTION VARCHAR(255),
          CONSTRAINT DEFAULTPROPERTIES_PK PRIMARY KEY (MODULETYPE, DATA_TYPE, PROPERTYNAME)
                ) TYPE=InnoDB
        ) by PASSTHRU;


      /*
       *  HCM default data values
       */

execute( Insert into EMPLOYEE_PROFILE (PROFILEID, PROFILE_NAME, DATASOURCE, KEYATTR, PROFILE_LABEL, DESCRIPTION, ADVSEARCHSTATUS, IDENTIFIER, LINKATTR, STYLESHEET, LSTYLE, DSTYLE) values ("EmployeeProfile", "EmployeeProfile", "EMPMAST",
         "EMPLOYEE_ID", "Employee Profile", "Employee Profile Document Metadata", 1, "EMPLOYEE_NAME", "EMPLOYEE_NAME", "", "", "") ) by PASSTHRU ;
execute( Insert into PROFILESEARCHATTR (PROFILEID,  SEARCHATTRID, ATTRIBUTEVALUE, LSTYLE, DSTYLE) values ("EmployeeProfile", "1", "EMPLOYEE_NAME", "", "")) by PASSTHRU ;
execute( Insert into PROFILESEARCHATTR (PROFILEID,  SEARCHATTRID, ATTRIBUTEVALUE, LSTYLE, DSTYLE) values ("EmployeeProfile", "2", "EMPLOYEE_ID", "", "")) by PASSTHRU ;
execute( Insert into PROFILESEARCHATTR (PROFILEID,  SEARCHATTRID, ATTRIBUTEVALUE, LSTYLE, DSTYLE) values ("EmployeeProfile", "3", "SOCIAL_SECURITY_NO", "", "")) by PASSTHRU ;
execute( Insert into PROFILESUMMARYATTR (PROFILEID, SUMMARYATTRID, ATTRIBUTEVALUE ,ATTRIBUTETABLE, LSTYLE, DSTYLE) values ("EmployeeProfile", "1", "EMPLOYEE_NAME", "", "tableHeader", "textTableCell")) by PASSTHRU ;
execute( Insert into PROFILESUMMARYATTR (PROFILEID, SUMMARYATTRID, ATTRIBUTEVALUE ,ATTRIBUTETABLE, LSTYLE, DSTYLE) values ("EmployeeProfile", "2", "EMPLOYEE_ID", "", "tableHeader", "textTableCell")) by PASSTHRU ;
execute( Insert into PROFILESUMMARYATTR (PROFILEID, SUMMARYATTRID, ATTRIBUTEVALUE ,ATTRIBUTETABLE, LSTYLE, DSTYLE) values ("EmployeeProfile", "3", "JOB_TITLE_TXT", "", "tableHeader", "textTableCell")) by PASSTHRU ;
execute( Insert into PROFILESUMMARYATTR (PROFILEID, SUMMARYATTRID, ATTRIBUTEVALUE ,ATTRIBUTETABLE, LSTYLE, DSTYLE) values ("EmployeeProfile", "4", "EMPLOYEE_STATUS_CD", "", "tableHeader", "textTableCell")) by PASSTHRU ;
execute( Insert into PROFILECATEGORY (PROFILEID, CATEGORYID, CATEGORYTYPE, CATEGORYLABEL, DATASOURCE, LSTYLE, DSTYLE) values ("EmployeeProfile", "1", "", "%getlabel(GENERAL,General)", "", "commonTitleRegular", "commonLabel")) by PASSTHRU ;
execute( Insert into PROFILECATEGORY (PROFILEID, CATEGORYID, CATEGORYTYPE, CATEGORYLABEL, DATASOURCE, LSTYLE, DSTYLE) values ("EmployeeProfile", "2", "", "%getlabel(POSITION,Position)", "","commonTitleRegular","commonLabel")) by PASSTHRU ;
execute( Insert into PROFILECATEGORY (PROFILEID, CATEGORYID, CATEGORYTYPE, CATEGORYLABEL, DATASOURCE, LSTYLE, DSTYLE) values ("EmployeeProfile", "3", "", "%getlabel(COMPENSATION,Compensation)", "","commonTitleRegular","commonLabel")) by PASSTHRU ;
execute( Insert into PROFILECATEGORYATTR (PROFILEID, CATEGORYID, CATEGORYATTRID, ATTRIBUTEVALUE, DATASOURCE, LSTYLE, DSTYLE) values ("EmployeeProfile", "1", "1", "JOB_GROUP_CD", "", "","")) by PASSTHRU ;
execute( Insert into PROFILECATEGORYATTR (PROFILEID, CATEGORYID, CATEGORYATTRID, ATTRIBUTEVALUE, DATASOURCE, LSTYLE, DSTYLE) values ("EmployeeProfile", "1", "2", "SOCIAL_SECURITY_NO", "", "","")) by PASSTHRU ;
execute( Insert into PROFILECATEGORYATTR (PROFILEID, CATEGORYID, CATEGORYATTRID, ATTRIBUTEVALUE, DATASOURCE, LSTYLE, DSTYLE) values ("EmployeeProfile", "1", "3", "CITIZENSHIP_COUNTRY_CD", "", "","")) by PASSTHRU ;
execute( Insert into PROFILECATEGORYATTR (PROFILEID, CATEGORYID, CATEGORYATTRID, ATTRIBUTEVALUE, DATASOURCE, LSTYLE, DSTYLE) values ("EmployeeProfile", "1", "4", "MILITARY_EXPERIENCE_DT", "", "","")) by PASSTHRU ;
execute( Insert into PROFILECATEGORYATTR (PROFILEID, CATEGORYID, CATEGORYATTRID, ATTRIBUTEVALUE, DATASOURCE, LSTYLE, DSTYLE) values ("EmployeeProfile", "1", "5", "HIRE_DT", "", "","")) by PASSTHRU ;
execute( Insert into PROFILECATEGORYATTR (PROFILEID, CATEGORYID, CATEGORYATTRID, ATTRIBUTEVALUE, DATASOURCE, LSTYLE, DSTYLE) values ("EmployeeProfile", "1", "6", "SERVICE_START_DT", "", "","")) by PASSTHRU ;
execute( Insert into PROFILECATEGORYATTR (PROFILEID, CATEGORYID, CATEGORYATTRID, ATTRIBUTEVALUE, DATASOURCE, LSTYLE, DSTYLE) values ("EmployeeProfile", "1", "8", "DISABILITY_FLG", "", "","")) by PASSTHRU ;
execute( Insert into PROFILECATEGORYATTR (PROFILEID, CATEGORYID, CATEGORYATTRID, ATTRIBUTEVALUE, DATASOURCE, LSTYLE, DSTYLE) values ("EmployeeProfile", "1", "9", "BIRTH_DT", "", "","")) by PASSTHRU ;
execute( Insert into PROFILECATEGORYATTR (PROFILEID, CATEGORYID, CATEGORYATTRID, ATTRIBUTEVALUE, DATASOURCE, LSTYLE, DSTYLE) values ("EmployeeProfile", "1", "10", "AGE", "", "","")) by PASSTHRU ;
execute( Insert into PROFILECATEGORYATTR (PROFILEID, CATEGORYID, CATEGORYATTRID, ATTRIBUTEVALUE, DATASOURCE, LSTYLE, DSTYLE) values ("EmployeeProfile", "1", "11", "MARITAL_STATUS_CD", "", "","")) by PASSTHRU ;
execute( Insert into PROFILECATEGORYATTR (PROFILEID, CATEGORYID, CATEGORYATTRID, ATTRIBUTEVALUE, DATASOURCE, LSTYLE, DSTYLE) values ("EmployeeProfile", "1", "12", "PERMANENCE_CD", "", "","")) by PASSTHRU ;
execute( Insert into PROFILECATEGORYATTR (PROFILEID, CATEGORYID, CATEGORYATTRID, ATTRIBUTEVALUE, DATASOURCE, LSTYLE, DSTYLE) values ("EmployeeProfile", "1", "13", "ETHNICITY_CD", "", "","")) by PASSTHRU ;
execute( Insert into PROFILECATEGORYATTR (PROFILEID, CATEGORYID, CATEGORYATTRID, ATTRIBUTEVALUE, DATASOURCE, LSTYLE, DSTYLE) values ("EmployeeProfile", "1", "14", "GENDER_CD", "", "","")) by PASSTHRU ;
execute( Insert into PROFILECATEGORYATTR (PROFILEID, CATEGORYID, CATEGORYATTRID, ATTRIBUTEVALUE, DATASOURCE, LSTYLE, DSTYLE) values ("EmployeeProfile", "1", "15", "ADDRESS_LINE_1_TXT", "", "","")) by PASSTHRU ;
execute( Insert into PROFILECATEGORYATTR (PROFILEID, CATEGORYID, CATEGORYATTRID, ATTRIBUTEVALUE, DATASOURCE, LSTYLE, DSTYLE) values ("EmployeeProfile", "1", "16", "ADDRESS_LINE_2_TXT", "", "","")) by PASSTHRU ;
execute( Insert into PROFILECATEGORYATTR (PROFILEID, CATEGORYID, CATEGORYATTRID, ATTRIBUTEVALUE, DATASOURCE, LSTYLE, DSTYLE) values ("EmployeeProfile", "1", "17", "CITY_NM", "", "","")) by PASSTHRU ;
execute( Insert into PROFILECATEGORYATTR (PROFILEID, CATEGORYID, CATEGORYATTRID, ATTRIBUTEVALUE, DATASOURCE, LSTYLE, DSTYLE) values ("EmployeeProfile", "1", "18", "COUNTRY_CD", "", "","")) by PASSTHRU ;
execute( Insert into PROFILECATEGORYATTR (PROFILEID, CATEGORYID, CATEGORYATTRID, ATTRIBUTEVALUE, DATASOURCE, LSTYLE, DSTYLE) values ("EmployeeProfile", "1", "19", "STATE_REGION_CD", "", "","")) by PASSTHRU ;
execute( Insert into PROFILECATEGORYATTR (PROFILEID, CATEGORYID, CATEGORYATTRID, ATTRIBUTEVALUE, DATASOURCE, LSTYLE, DSTYLE) values ("EmployeeProfile", "1", "20", "POSTAL_CD", "", "","")) by PASSTHRU ;
execute( Insert into PROFILECATEGORYATTR (PROFILEID, CATEGORYID, CATEGORYATTRID, ATTRIBUTEVALUE, DATASOURCE, LSTYLE, DSTYLE) values ("EmployeeProfile", "1", "21", "COUNTY_NM", "", "","")) by PASSTHRU ;
execute( Insert into PROFILECATEGORYATTR (PROFILEID, CATEGORYID, CATEGORYATTRID, ATTRIBUTEVALUE, DATASOURCE, LSTYLE, DSTYLE) values ("EmployeeProfile", "1", "22", "CURRENCY_CD", "", "","")) by PASSTHRU ;
execute( Insert into PROFILECATEGORYATTR (PROFILEID, CATEGORYID, CATEGORYATTRID, ATTRIBUTEVALUE, DATASOURCE, LSTYLE, DSTYLE) values ("EmployeeProfile", "1", "23", "HOURS_PER_WEEK_CNT", "", "","")) by PASSTHRU ;
execute( Insert into PROFILECATEGORYATTR (PROFILEID, CATEGORYID, CATEGORYATTRID, ATTRIBUTEVALUE, DATASOURCE, LSTYLE, DSTYLE) values ("EmployeeProfile", "2", "1", "POSITION_CD", "", "","")) by PASSTHRU ;
execute( Insert into PROFILECATEGORYATTR (PROFILEID, CATEGORYID, CATEGORYATTRID, ATTRIBUTEVALUE, DATASOURCE, LSTYLE, DSTYLE) values ("EmployeeProfile", "2", "2", "POSITION_STATUS_CD", "", "","")) by PASSTHRU ;
execute( Insert into PROFILECATEGORYATTR (PROFILEID, CATEGORYID, CATEGORYATTRID, ATTRIBUTEVALUE, DATASOURCE, LSTYLE, DSTYLE) values ("EmployeeProfile", "2", "3", "JOB_GROUP_CD", "", "","")) by PASSTHRU ;
execute( Insert into PROFILECATEGORYATTR (PROFILEID, CATEGORYID, CATEGORYATTRID, ATTRIBUTEVALUE, DATASOURCE, LSTYLE, DSTYLE) values ("EmployeeProfile", "2", "4", "JOB_GROUP_DESC", "", "","")) by PASSTHRU ;
execute( Insert into PROFILECATEGORYATTR (PROFILEID, CATEGORYID, CATEGORYATTRID, ATTRIBUTEVALUE, DATASOURCE, LSTYLE, DSTYLE) values ("EmployeeProfile", "2", "5", "JOB_CD", "", "","")) by PASSTHRU ;
execute( Insert into PROFILECATEGORYATTR (PROFILEID, CATEGORYID, CATEGORYATTRID, ATTRIBUTEVALUE, DATASOURCE, LSTYLE, DSTYLE) values ("EmployeeProfile", "2", "6", "PAY_LEVEL_CD", "", "","")) by PASSTHRU ;
execute( Insert into PROFILECATEGORYATTR (PROFILEID, CATEGORYID, CATEGORYATTRID, ATTRIBUTEVALUE, DATASOURCE, LSTYLE, DSTYLE) values ("EmployeeProfile", "2", "7", "UNION_CD", "", "","")) by PASSTHRU ;
execute( Insert into PROFILECATEGORYATTR (PROFILEID, CATEGORYID, CATEGORYATTRID, ATTRIBUTEVALUE, DATASOURCE, LSTYLE, DSTYLE) values ("EmployeeProfile", "2", "8", "POS_FTE_RT", "", "","")) by PASSTHRU ;
execute( Insert into PROFILECATEGORYATTR (PROFILEID, CATEGORYID, CATEGORYATTRID, ATTRIBUTEVALUE, DATASOURCE, LSTYLE, DSTYLE) values ("EmployeeProfile", "2", "9", "PERMANENCE_CD", "", "","")) by PASSTHRU ;
execute( Insert into PROFILECATEGORYATTR (PROFILEID, CATEGORYID, CATEGORYATTRID, ATTRIBUTEVALUE, DATASOURCE, LSTYLE, DSTYLE) values ("EmployeeProfile", "2", "10", "EXEMPT_STATUS_CD", "", "","")) by PASSTHRU ;
execute( Insert into PROFILECATEGORYATTR (PROFILEID, CATEGORYID, CATEGORYATTRID, ATTRIBUTEVALUE, DATASOURCE, LSTYLE, DSTYLE) values ("EmployeeProfile", "2", "11", "PAY_LEVEL_STRUCTURE_CD", "", "","")) by PASSTHRU ;
execute( Insert into PROFILECATEGORYATTR (PROFILEID, CATEGORYID, CATEGORYATTRID, ATTRIBUTEVALUE, DATASOURCE, LSTYLE, DSTYLE) values ("EmployeeProfile", "2", "12", "FTEQUIV", "", "","")) by PASSTHRU ;
execute( Insert into PROFILECATEGORYATTR (PROFILEID, CATEGORYID, CATEGORYATTRID, ATTRIBUTEVALUE, DATASOURCE, LSTYLE, DSTYLE) values ("EmployeeProfile", "2", "13", "FTE_RT", "", "","")) by PASSTHRU ;
execute( Insert into PROFILECATEGORYATTR (PROFILEID, CATEGORYID, CATEGORYATTRID, ATTRIBUTEVALUE, DATASOURCE, LSTYLE, DSTYLE) values ("EmployeeProfile", "3", "1", "PAY_LEVEL_STRUCTURE_CD", "", "","")) by PASSTHRU ;
execute( Insert into PROFILECATEGORYATTR (PROFILEID, CATEGORYID, CATEGORYATTRID, ATTRIBUTEVALUE, DATASOURCE, LSTYLE, DSTYLE) values ("EmployeeProfile", "3", "2", "MONTHLY_SALARY", "", "","")) by PASSTHRU ;
execute( Insert into PROFILECATEGORYATTR (PROFILEID, CATEGORYID, CATEGORYATTRID, ATTRIBUTEVALUE, DATASOURCE, LSTYLE, DSTYLE) values ("EmployeeProfile", "3", "3", "ANNUAL_SALARY", "", "","")) by PASSTHRU ;
execute( Insert into PROFILECATEGORYATTR (PROFILEID, CATEGORYID, CATEGORYATTRID, ATTRIBUTEVALUE, DATASOURCE, LSTYLE, DSTYLE) values ("EmployeeProfile", "3", "4", "MIDPOINT_AMT", "", "","")) by PASSTHRU ;
execute( Insert into PROFILECATEGORYATTR (PROFILEID, CATEGORYID, CATEGORYATTRID, ATTRIBUTEVALUE, DATASOURCE, LSTYLE, DSTYLE) values ("EmployeeProfile", "3", "5", "HOURS_PER_WEEK_CNT", "", "","")) by PASSTHRU ;
execute( Insert into PROFILECATEGORYATTR (PROFILEID, CATEGORYID, CATEGORYATTRID, ATTRIBUTEVALUE, DATASOURCE, LSTYLE, DSTYLE) values ("EmployeeProfile", "3", "6", "PAY_GRADE_FREQUENCY_CD", "", "","")) by PASSTHRU ;
execute( Insert into PROFILECATEGORYATTR (PROFILEID, CATEGORYID, CATEGORYATTRID, ATTRIBUTEVALUE, DATASOURCE, LSTYLE, DSTYLE) values ("EmployeeProfile", "3", "7", "PAY_LEVEL_CD", "", "","")) by PASSTHRU ;
execute( Insert into PROFILECATEGORYATTR (PROFILEID, CATEGORYID, CATEGORYATTRID, ATTRIBUTEVALUE, DATASOURCE, LSTYLE, DSTYLE) values ("EmployeeProfile", "3", "8", "MINIMUM_AMT", "", "","")) by PASSTHRU ;
execute( Insert into PROFILECATEGORYATTR (PROFILEID, CATEGORYID, CATEGORYATTRID, ATTRIBUTEVALUE, DATASOURCE, LSTYLE, DSTYLE) values ("EmployeeProfile", "3", "9", "MAXIMUM_AMT", "", "","")) by PASSTHRU ;
execute( Insert into PROFILEHEADERATTR (PROFILEID, HEADERATTRID, ATTRIBUTEVALUE, DATASOURCE, LSTYLE, DSTYLE) values ("EmployeeProfile", "1", "EMPLOYEE_NAME", "", "commonInfoTitle", "commonHeading")) by PASSTHRU ;
execute( Insert into PROFILEHEADERATTR (PROFILEID, HEADERATTRID, ATTRIBUTEVALUE, DATASOURCE, LSTYLE, DSTYLE) values ("EmployeeProfile", "2", "EMPLOYEE_ID", "", "commonInfoTitle", "commonLabel")) by PASSTHRU ;
execute( Insert into PROFILEHEADERATTR (PROFILEID, HEADERATTRID, ATTRIBUTEVALUE, DATASOURCE, LSTYLE, DSTYLE) values ("EmployeeProfile", "3", "SOCIAL_SECURITY_NO", "", "commonInfoTitle", "commonLabel")) by PASSTHRU ;
execute( Insert into PROFILEHEADERATTR (PROFILEID, HEADERATTRID, ATTRIBUTEVALUE, DATASOURCE, LSTYLE, DSTYLE) values ("EmployeeProfile", "4", "JOB_TITLE_TXT", "", "commonInfoTitle", "commonLabel")) by PASSTHRU ;
execute( Insert into PROFILETABLEATTR (PROFILEID, USERID, TABLEID, DATASOURCE, MODELID, MENULABEL) values ("EmployeeProfile", "SAS Administrator", "1", "ABSHIST", "1", "%getlabel(ABSHIST,Absence History)")) by PASSTHRU ;
execute( Insert into PROFILETABLEATTR (PROFILEID, USERID, TABLEID, DATASOURCE, MODELID, MENULABEL) values ("EmployeeProfile", "SAS Administrator", "2", "SALHIST", "2", "%getlabel(SALHIST,Salary History)")) by PASSTHRU ;
execute( Insert into EXCLUSIONLIST(MODULETYPE,TABLENAME,COLUMNNAME,DATA_TYPE) values ("Org", "EMPMAST", "SRVYRS",0)) by PASSTHRU ;
execute( Insert into EXCLUSIONLIST(MODULETYPE,TABLENAME,COLUMNNAME,DATA_TYPE) values ("Org", "EMPMAST", "PCT_OVER_MAXIMUM",0)) by PASSTHRU ;
execute( Insert into EXCLUSIONLIST(MODULETYPE,TABLENAME,COLUMNNAME,DATA_TYPE) values ("Org", "EMPMAST", "HIRE_DT",0)) by PASSTHRU ;
execute( Insert into DEFAULTPROPERTIES(MODULETYPE,DATA_TYPE,PROPERTYNAME,DEFAULTVALUE,DESCRIPTION)values ('Org',1,'NodeAttributes','Description','Node Attributes')) by PASSTHRU ;
execute( Insert into DEFAULTPROPERTIES(MODULETYPE,DATA_TYPE,PROPERTYNAME,DEFAULTVALUE,DESCRIPTION)values ('Org',1,'spGUID','orgProcGUID','GUID of Stored Procedure')) by PASSTHRU ;
execute( Insert into DEFAULTPROPERTIES(MODULETYPE,DATA_TYPE,PROPERTYNAME,DEFAULTVALUE,DESCRIPTION)values ('Org',1,'Measures','HCNT','Head Count Measure')) by PASSTHRU ;
execute( Insert into DEFAULTPROPERTIES(MODULETYPE,DATA_TYPE,PROPERTYNAME,DEFAULTVALUE,DESCRIPTION)values ('Org',1,'IsModified','false','Doc is modified or not')) by PASSTHRU ;
execute( Insert into DEFAULTPROPERTIES(MODULETYPE,DATA_TYPE,PROPERTYNAME,DEFAULTVALUE,DESCRIPTION)values ('Org',1,'HierarchySource','HCM','ODCS or HCM Tables to use to build OrgModel and get hierarchies')) by PASSTHRU;
execute( Insert into DEFAULTPROPERTIES(MODULETYPE,DATA_TYPE,PROPERTYNAME,DEFAULTVALUE,DESCRIPTION)values ('Org','1','Employee_Status_Cd_Column','EMPLOYEE_STATUS_CD','Column Name for Employee Status Code')) by PASSTHRU;
execute( Insert into DEFAULTPROPERTIES(MODULETYPE,DATA_TYPE,PROPERTYNAME,DEFAULTVALUE,DESCRIPTION)values ('Org','1','Employee_Status_Cd_Value','A','Default Value for Employee Status Code')) by PASSTHRU;
execute( Insert into DEFAULTPROPERTIES(MODULETYPE,DATA_TYPE,PROPERTYNAME,DEFAULTVALUE,DESCRIPTION)values ('Org','1','Unassigned','UNASSIGNED','Unassigned Node Namme')) by PASSTHRU;
execute( Insert into DEFAULTPROPERTIES(MODULETYPE,DATA_TYPE,PROPERTYNAME,DEFAULTVALUE,DESCRIPTION)values ('EEP',2,'ProfileId', 'EmployeeProfile', 'Default Employee Profile Id')) by PASSTHRU ;
execute( Insert into DEFAULTPROPERTIES(MODULETYPE,DATA_TYPE,PROPERTYNAME,DEFAULTVALUE,DESCRIPTION)values ('Geo', 1, 'geoTable', 'HCMData.EMPMAST', 'geoTable')) by PASSTHRU ;
execute( Insert into DEFAULTPROPERTIES(MODULETYPE,DATA_TYPE,PROPERTYNAME,DEFAULTVALUE,DESCRIPTION)values ('Geo', 1, 'legendLabel', 'Employee Population', 'legendLabel')) by PASSTHRU ;
execute( Insert into DEFAULTPROPERTIES(MODULETYPE,DATA_TYPE,PROPERTYNAME,DEFAULTVALUE,DESCRIPTION)values ('Geo', 1, 'analysisFields', 'MONTHLY_SALARY-MAX~ANNUAL_SALARY-MIN', 'analysisFields')) by PASSTHRU ;
execute( Insert into DEFAULTPROPERTIES(MODULETYPE,DATA_TYPE,PROPERTYNAME,DEFAULTVALUE,DESCRIPTION)values ('Geo', 1, 'statistics', 'N MIN MAX MEAN', 'statistics')) by PASSTHRU ;
execute( Insert into DEFAULTPROPERTIES(MODULETYPE,DATA_TYPE,PROPERTYNAME,DEFAULTVALUE,DESCRIPTION)values ('Geo', 1, 'legendLevels', '3', 'legendLevels')) by PASSTHRU ;
execute( Insert into DEFAULTPROPERTIES(MODULETYPE,DATA_TYPE,PROPERTYNAME,DEFAULTVALUE,DESCRIPTION)values ('Geo', 1, 'maplevel_1', 'MAPS.HRV_GBL', 'maplevel_1')) by PASSTHRU ;
execute( Insert into DEFAULTPROPERTIES(MODULETYPE,DATA_TYPE,PROPERTYNAME,DEFAULTVALUE,DESCRIPTION)values ('Geo', 1, 'maplevel_2', 'MAPS.HRV_US', 'maplevel_2')) by PASSTHRU ;
execute( Insert into DEFAULTPROPERTIES(MODULETYPE,DATA_TYPE,PROPERTYNAME,DEFAULTVALUE,DESCRIPTION)values ('Geo', 1, 'maplevel_3', 'MAPS.HRV_STATE', 'maplevel_3')) by PASSTHRU ;
execute( Insert into DEFAULTPROPERTIES(MODULETYPE,DATA_TYPE,PROPERTYNAME,DEFAULTVALUE,DESCRIPTION)values ('Geo', 1, 'maplevel_4', '', 'maplevel_4')) by PASSTHRU ;
execute( Insert into DEFAULTPROPERTIES(MODULETYPE,DATA_TYPE,PROPERTYNAME,DEFAULTVALUE,DESCRIPTION)values ('Geo', 1, 'maplevel_5', '', 'maplevel_5')) by PASSTHRU ;
execute( Insert into DEFAULTPROPERTIES(MODULETYPE,DATA_TYPE,PROPERTYNAME,DEFAULTVALUE,DESCRIPTION)values ('Geo', 1, 'maplevel_6', '', 'maplevel_6')) by PASSTHRU ;
execute( Insert into DEFAULTPROPERTIES(MODULETYPE,DATA_TYPE,PROPERTYNAME,DEFAULTVALUE,DESCRIPTION)values ('Geo', 1, 'displayfields_1', 'COUNTRY_CD', 'displayfields_1')) by PASSTHRU ;
execute( Insert into DEFAULTPROPERTIES(MODULETYPE,DATA_TYPE,PROPERTYNAME,DEFAULTVALUE,DESCRIPTION)values ('Geo', 1, 'displayfields_2', 'COUNTRY_CD STATE_REGION_CD', 'displayfields_2')) by PASSTHRU ;
execute( Insert into DEFAULTPROPERTIES(MODULETYPE,DATA_TYPE,PROPERTYNAME,DEFAULTVALUE,DESCRIPTION)values ('Geo', 1, 'displayfields_3', 'COUNTRY_CD STATE_REGION_CD COUNTY_NM', 'displayfields_3')) by PASSTHRU ;
execute( Insert into DEFAULTPROPERTIES(MODULETYPE,DATA_TYPE,PROPERTYNAME,DEFAULTVALUE,DESCRIPTION)values ('Geo', 1, 'displayfields_4', '', 'displayfields_4')) by PASSTHRU ;
execute( Insert into DEFAULTPROPERTIES(MODULETYPE,DATA_TYPE,PROPERTYNAME,DEFAULTVALUE,DESCRIPTION)values ('Geo', 1, 'displayfields_5', '', 'displayfields_5')) by PASSTHRU ;
execute( Insert into DEFAULTPROPERTIES(MODULETYPE,DATA_TYPE,PROPERTYNAME,DEFAULTVALUE,DESCRIPTION)values ('Geo', 1, 'displayfields_6', '', 'displayfields_6')) by PASSTHRU ;
execute( Insert into DEFAULTPROPERTIES(MODULETYPE,DATA_TYPE,PROPERTYNAME,DEFAULTVALUE,DESCRIPTION)values ('Geo', 1, 'link_1', 'COUNTRY_CD', 'link_1')) by PASSTHRU ;
execute( Insert into DEFAULTPROPERTIES(MODULETYPE,DATA_TYPE,PROPERTYNAME,DEFAULTVALUE,DESCRIPTION)values ('Geo', 1, 'link_2', 'STATE_REGION_CD', 'link_2')) by PASSTHRU ;
execute( Insert into DEFAULTPROPERTIES(MODULETYPE,DATA_TYPE,PROPERTYNAME,DEFAULTVALUE,DESCRIPTION)values ('Geo', 1, 'link_3', 'COUNTY_NM', 'link_3')) by PASSTHRU ;
execute( Insert into DEFAULTPROPERTIES(MODULETYPE,DATA_TYPE,PROPERTYNAME,DEFAULTVALUE,DESCRIPTION)values ('Geo', 1, 'link_4', '', 'link_4')) by PASSTHRU ;
execute( Insert into DEFAULTPROPERTIES(MODULETYPE,DATA_TYPE,PROPERTYNAME,DEFAULTVALUE,DESCRIPTION)values ('Geo', 1, 'link_5', '', 'link_5')) by PASSTHRU ;
execute( Insert into DEFAULTPROPERTIES(MODULETYPE,DATA_TYPE,PROPERTYNAME,DEFAULTVALUE,DESCRIPTION)values ('Geo', 1, 'link_6', '', 'link_6')) by PASSTHRU ;
execute( Insert into DEFAULTPROPERTIES(MODULETYPE,DATA_TYPE,PROPERTYNAME,DEFAULTVALUE,DESCRIPTION)values ('Geo', 1, 'profiledocid', 'EmployeeProfile', 'profiledocid')) by PASSTHRU ;
execute( Insert into DEFAULTPROPERTIES(MODULETYPE,DATA_TYPE,PROPERTYNAME,DEFAULTVALUE,DESCRIPTION)values ('Geo', 1, 'spGUID', '2261dd9e-ac19-e7ed-007f-8baf21a19872', 'spGUID')) by PASSTHRU ;
execute( Insert into DEFAULTPROPERTIES(MODULETYPE,DATA_TYPE,PROPERTYNAME,DEFAULTVALUE,DESCRIPTION)values ('Geo', 1, 'isHeadcount', 'Y', 'Headcount Analysis')) by PASSTHRU ;
execute( Insert into DEFAULTPROPERTIES(MODULETYPE,DATA_TYPE,PROPERTYNAME,DEFAULTVALUE,DESCRIPTION)values ('Config', 1, 'SecureGroup', 'HR', 'HCM Power Users Group')) by PASSTHRU ;
execute( Insert into DEFAULTPROPERTIES(MODULETYPE,DATA_TYPE,PROPERTYNAME,DEFAULTVALUE,DESCRIPTION)values ('Config', 1, 'MartLocale', '', 'HCM Datamart Locale')) by PASSTHRU ;
execute( Insert into DEFAULTPROPERTIES(MODULETYPE,DATA_TYPE,PROPERTYNAME,DEFAULTVALUE,DESCRIPTION)values ('Config', 1, 'PropFilePath', '', 'Path to Property Files')) by PASSTHRU ;
execute( Insert into DEFAULTPROPERTIES(MODULETYPE,DATA_TYPE,PROPERTYNAME,DEFAULTVALUE,DESCRIPTION)values ('Config', 1, 'CurrencyFmt', 'DOLLAR14.2', 'Default Currency Format')) by PASSTHRU ;
execute( Insert into DEFAULTPROPERTIES(MODULETYPE,DATA_TYPE,PROPERTYNAME,DEFAULTVALUE,DESCRIPTION)values ('Config', 1, 'DateFmt', 'DATE9.', 'Default Date Format')) by PASSTHRU ;
execute( Insert into DEFAULTPROPERTIES(MODULETYPE,DATA_TYPE,PROPERTYNAME,DEFAULTVALUE,DESCRIPTION)values ('Org', 1, 'HideEmployee', 'false', 'Hide Employee Nodes from Org Analysis')) by PASSTHRU ;

disconnect from PASSTHRU ;

QUIT;

/* Create Data Dictionary tables */
%createdd;

%MEND;
