%macro updatedd(tablenm=);

/* set the locale macro variables */
%setlocs;

/* define the label macros for the build programs to use */
%readlbls(basedir=&propspth,basefile=&lblprops,baseext=properties,slash=&slash,defaultpath=);

options metarepository="&HRRepos";
%LibConOp(sesetl_sasLibRef=&hcmlib,
         sesetl_ChkDepRepos=Y
         ) ;
run;

%local tblid highid;

/* Look up table ID in SAS_HCMMETATABLE using the tablenm parameter */
data _null_;
  set &hcmlib..SAS_HCMMETATABLE;
  if upcase(HCM_TABLE_NAME)="%upcase(&tablenm)";
  call symput("TBLID",left(put(ID,11.)));
  stop;
run;

%if &tblid= %then %do;
 %put ERROR: There is no match found in SAS_HCMMETATABLE for Table %upcase(&tablenm);
 %goto exit;
%end;

/* find the highest ID value */
data _null_;
  set &hcmlib..SAS_HCMMETACOLUMN nobs=numobs;
  if numobs gt 0 then do;
   retain highid;
   if ID > highid then do;
     highid=id;
     call symput("highid",left(put(highid,11.)));
  end;
  else;%let highid=1;
  end;
run;


/* get the rows in SAS_HCMMETACOLUMN table for the table to be updated  */
data SAS_HCMMETACOLUMN;
  set &hcmlib..SAS_HCMMETACOLUMN;
  if TABLEID=&tblid;
  HCM_COLUMN_NAME=upcase(HCM_COLUMN_NAME);
run;
proc sort;by HCM_COLUMN_NAME;
run;

/* create a dataset with the list of columns of the table to be updated */
/* these need to be validated against the data dictionary               */
proc contents data=&hcmlib..%upcase(&tablenm) noprint out=temp2(keep=NAME TYPE LENGTH);
run;
/* rename the name column from the proc contents to hcm_column_name and upcase it  */
/* rename the type column from the proc contents to data_type                      */
data temp2;
  set temp2(rename=(name=HCM_COLUMN_NAME type=DATA_TYPE));
  HCM_COLUMN_NAME=upcase(HCM_COLUMN_NAME);
  proc sort;by HCM_COLUMN_NAME;
run;

/* merge the list of columns from the table just built and from the data dict. */
/* find records to be deleted from the data dictionary                         */
data delete;
  merge SAS_HCMMETACOLUMN(in=a keep=HCM_COLUMN_NAME TABLEID ID) temp2(in=b keep=HCM_COLUMN_NAME);
  by HCM_COLUMN_NAME;
  if a and not b;
run;
proc sort;
  by TABLEID HCM_COLUMN_NAME;
run;

proc format;
  value typefmt 1="NUM" other="CHAR";
run;

/* find records to be added to the data dictionary           */
/* add the additional columns needed for the data dictionary */
data add(drop=charnum);
  retain ID &highid;
  length  COLUMN_LABEL $200. FORMAT  $32. DESCRIPTION $100. DATA_TYPE $10. ID TABLEID DISPLAYORDER
        ISHIDDEN USEFMT ISANALYSIS STAT_COUNT
        NMISS STAT_SUM STAT_MAX STAT_MIN USS STAT_AVG STAT_RANGE CSS VAR STD STDERR CV T PRT LCLM UCLM 8.;
  merge SAS_HCMMETACOLUMN(in=a drop=ID TABLEID) temp2(in=b rename=(DATA_TYPE=CHARNUM));
  by HCM_COLUMN_NAME;
  if b and not a;
  ID=ID + 1;
  TABLEID=&tblid;

  macrocall = '%getlabel(' || HCM_COLUMN_NAME ||',' || HCM_COLUMN_NAME || ',Y)';
  call execute(macrocall);
  COLUMN_LABEL = symget('getlabel_return');
  DATA_TYPE=put(charnum,typefmt.);
  DISPLAYORDER=0;
  ISHIDDEN=0;USEFMT=1;ISANALYSIS=0;STAT_COUNT=1;STAT_MIN=1;STAT_MAX=1;STAT_SUM=1;NMISS=1;USS=1;STAT_AVG=1;STAT_RANGE=1;
  CSS=1; VAR=1; STD=1; STDERR=1; CV=1; T=1; PRT=1; LCLM=1; UCLM=1;
run;

/* Read the SAS_HCMMETACOLUMN, delete the unused columns and place the results in a work table */
/* to be inserted back into the SAS_HCMMETACOLUMN table later                                  */
proc sort data=SAS_HCMMETACOLUMN;
  by TABLEID HCM_COLUMN_NAME;
run;
data SAS_HCMMETACOLUMN;
  merge delete(in=a) SAS_HCMMETACOLUMN(in=b);
  by TABLEID HCM_COLUMN_NAME;
  if a and b then delete;
 run;

/* Delete all the records from the current SAS_HCMMETACOLUMN table */
proc sql;
    connect to &sesetl_EngineType as PASSTHRU
               (&sesetl_BestLogin &sesetl_ConnectionOptions );
       execute(delete from SAS_HCMMETACOLUMN where TABLEID=&tblid
               ) by PASSTHRU;
    disconnect from PASSTHRU;
QUIT;



 /* insert the original records with the deletes and the add records back into SAS_HCMMETACOLUMN */
 proc sql;
  insert into &hcmlib..SAS_HCMMETACOLUMN
   select ID,TABLEID,HCM_COLUMN_NAME,COLUMN_LABEL,DESCRIPTION,DATA_TYPE,FORMAT,DISPLAYORDER,ISHIDDEN,USEFMT,ISANALYSIS,STAT_COUNT,
   NMISS, STAT_SUM, STAT_MAX, STAT_MIN, USS, STAT_AVG, STAT_RANGE, CSS, VAR, STD, STDERR, CV, T, PRT, LCLM, UCLM
    from SAS_HCMMETACOLUMN;
  insert into &hcmlib..SAS_HCMMETACOLUMN
   select ID,TABLEID,HCM_COLUMN_NAME,COLUMN_LABEL,DESCRIPTION,DATA_TYPE,FORMAT,DISPLAYORDER,ISHIDDEN,USEFMT,ISANALYSIS,STAT_COUNT,
   NMISS, STAT_SUM, STAT_MAX, STAT_MIN, USS, STAT_AVG, STAT_RANGE, CSS, VAR, STD, STDERR, CV, T, PRT, LCLM, UCLM
    from add;
 quit;

/*Update the column labels for ADD1, ADDD2,...,ADDn if the table is SALHSUM.  This is a change for the HCM 4.4 hotfix.*/
%global addn;
%If &addn.>0 and %upcase(&tablenm)=SALHSUM %then %do;
Proc sql;
    connect to &sesetl_EngineType as PASSTHRU
               (&sesetl_BestLogin &sesetl_ConnectionOptions );
%Do k=1 %to &addn.;
       execute(
 Update SAS_HCMMETACOLUMN
 Set COLUMN_LABEL="&&add&k._label."    /*These global macro variables are initialized in the source code for SALHSUM.*/
 Where upper(HCM_COLUMN_NAME)="ADD&k." and TABLEID=&tblid.
       ) by PASSTHRU;
%End;
    disconnect from PASSTHRU;
Quit;
%End;
%let addn=;

%exit:

%mend;
